@@ -5,9 +5,8 @@
 
     Lexers for math languages.
 
-    :copyright: 2007-2008 by Christopher Creutzig, Ken Schutte, Stou Sandalski,
-                Laurent Gautier <lgautier@gmail.com>.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 import re
@@ -16,7 +15,7 @@ try:
 except NameError:
     from sets import Set as set
 
-from pygments.lexer import Lexer, RegexLexer, bygroups, include
+from pygments.lexer import Lexer, RegexLexer, bygroups, include, do_insertions
 from pygments.token import Comment, String, Punctuation, Keyword, Name, \
     Operator, Number, Text, Generic
 
@@ -159,14 +158,14 @@ class MatlabLexer(RegexLexer):
             (r'^\s*function', Keyword, 'deffunc'),
 
             # from 'iskeyword' on version 7.4.0.336 (R2007a):
-            (r'break|case|catch|classdef|continue|else|elseif|end|for|function|'
-             r'global|if|otherwise|parfor|persistent|return|switch|try|while',
+            (r'(break|case|catch|classdef|continue|else|elseif|end|for|function|'
+             r'global|if|otherwise|parfor|persistent|return|switch|try|while)\b',
              Keyword),
 
-            ("|".join(elfun+specfun+elmat), Name.Builtin),
+            ("(" + "|".join(elfun+specfun+elmat) + r')\b',  Name.Builtin),
 
             # operators:
-            (r'-|==|~=|<|>|<=|>=|&&|&|~', Operator),
+            (r'-|==|~=|<|>|<=|>=|&&|&|~|\|\|?', Operator),
             # operators requiring escape for re:
             (r'\.\*|\*|\+|\.\^|\.\\|\.\/|\/|\\', Operator),
 
@@ -175,22 +174,30 @@ class MatlabLexer(RegexLexer):
             (r'=|:|;', Punctuation),
 
             # quote can be transpose, instead of string:
-            (r'(\w+)(\')', bygroups(Text, Operator)),
+            # (not great, but handles common cases...)
+            (r'(?<=[\w\)\]])\'', Operator),
 
-            (r'\'', String, 'string'),
+            (r'(?<![\w\)\]])\'', String, 'string'),
+            ('[a-zA-Z_][a-zA-Z0-9_]*', Name),
             (r'.', Text),
         ],
         'string': [
             (r'[^\']*\'', String, '#pop')
         ],
         'deffunc': [
-            (r'(\s*)(.+)(\s*)(=)(\s*)(.+)(\()(.*)(\))(\s*)',
+            (r'(\s*)(?:(.+)(\s*)(=)(\s*))?(.+)(\()(.*)(\))(\s*)',
              bygroups(Text.Whitespace, Text, Text.Whitespace, Punctuation,
                       Text.Whitespace, Name.Function, Punctuation, Text,
                       Punctuation, Text.Whitespace), '#pop'),
         ],
     }
 
+    def analyse_text(text):
+        if re.match('^\s*%', text, re.M): # comment
+            return 0.9
+        elif re.match('^!\w+', text, re.M): # system cmd
+            return 0.9
+        return 0.1
 
 line_re  = re.compile('.*?\n')
 
@@ -255,6 +262,7 @@ class NumPyLexer(PythonLexer):
 
     # override the mimetypes to not inherit them from python
     mimetypes = []
+    filenames = []
 
     EXTRA_KEYWORDS = set([
         'abs', 'absolute', 'accumulate', 'add', 'alen', 'all', 'allclose',
@@ -361,21 +369,24 @@ class SLexer(RegexLexer):
              Keyword.Reserved)
         ],
         'operators': [
-            (r'<-|-|==|<=|>=|<|>|&&|&|!=', Operator),
+            (r'<-|-|==|<=|>=|<|>|&&|&|!=|\|\|?', Operator),
             (r'\*|\+|\^|/|%%|%/%|=', Operator),
             (r'%in%|%*%', Operator)
         ],
         'builtin_symbols': [
-            (r'NULL|NA|TRUE|FALSE', Keyword.Constant),
+            (r'(NULL|NA|TRUE|FALSE|NaN)\b', Keyword.Constant),
+            (r'(T|F)\b', Keyword.Variable),
         ],
         'numbers': [
             (r'(?<![0-9a-zA-Z\)\}\]`\"])(?=\s*)[-\+]?[0-9]+'
              r'(\.[0-9]*)?(E[0-9][-\+]?(\.[0-9]*)?)?', Number),
+            (r'\.[0-9]*(E[0-9][-\+]?(\.[0-9]*)?)?', Number),
         ],
         'statements': [
             include('comments'),
             # whitespaces
             (r'\s+', Text),
+            (r'\'', String, 'string_squote'),
             (r'\"', String, 'string_dquote'),
             include('builtin_symbols'),
             include('numbers'),
@@ -396,7 +407,13 @@ class SLexer(RegexLexer):
         #    ('\{', Punctuation, '#push'),
         #    ('\}', Punctuation, '#pop')
         #],
+        'string_squote': [
+            (r'[^\']*\'', String, '#pop'),
+        ],
         'string_dquote': [
             (r'[^\"]*\"', String, '#pop'),
         ],
     }
+
+    def analyse_text(text):
+        return '<-' in text
