@@ -8,8 +8,8 @@
     the text where Error tokens are being generated, along
     with some context.
 
-    :copyright: 2006 by Tim Hatch <tim@timhatch.com>.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2009 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 import sys, os
@@ -40,12 +40,20 @@ def main(fn):
     for type, val in lx.get_tokens(text):
         if type == Error:
             print "Error parsing", fn
-            print "\n".join(['   ' + repr(x) for x in ntext[-5:]])
+            print "\n".join(['   ' + repr(x) for x in ntext[-num:]])
             print `val` + "<<<"
-            return
+            return 1
         ntext.append((type,val))
+    return 0
 
 
+num = 10
+
 if __name__ == "__main__":
+    if sys.argv[1][:2] == '-n':
+        num = int(sys.argv[1][2:])
+        del sys.argv[1]
+    ret = 0
     for f in sys.argv[1:]:
-        main(f)
+        ret += main(f)
+    sys.exit(bool(ret))
